==> adas.utils_1.0.0.tar.gz: adas.utils/R/adas.utils-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr across
#' @importFrom dplyr add_row
#' @importFrom dplyr arrange
#' @importFrom dplyr bind_rows
#' @importFrom dplyr c_across
#' @importFrom dplyr desc
#' @importFrom dplyr filter
#' @importFrom dplyr if_else
#' @importFrom dplyr mutate
#' @importFrom dplyr n
#' @importFrom dplyr pull
#' @importFrom dplyr relocate
#' @importFrom dplyr rename_with
#' @importFrom dplyr rowwise
#' @importFrom dplyr select
#' @importFrom dplyr slice_tail
#' @importFrom dplyr summarize_all
#' @importFrom dplyr ungroup
#' @importFrom gghalfnorm gghalfnorm
#' @importFrom ggplot2 aes
#' @importFrom ggplot2 coord_cartesian
#' @importFrom ggplot2 element_text
#' @importFrom ggplot2 geom_col
#' @importFrom ggplot2 geom_function
#' @importFrom ggplot2 geom_hline
#' @importFrom ggplot2 geom_label
#' @importFrom ggplot2 geom_line
#' @importFrom ggplot2 geom_point
#' @importFrom ggplot2 geom_qq
#' @importFrom ggplot2 geom_qq_line
#' @importFrom ggplot2 geom_tile
#' @importFrom ggplot2 ggplot
#' @importFrom ggplot2 labs
#' @importFrom ggplot2 scale_fill_viridis_d
#' @importFrom ggplot2 scale_y_continuous
#' @importFrom ggplot2 sec_axis
#' @importFrom ggplot2 stat_qq
#' @importFrom ggplot2 theme
#' @importFrom glue glue
#' @importFrom grDevices grey
#' @importFrom lubridate stamp
#' @importFrom purrr accumulate
#' @importFrom purrr discard
#' @importFrom purrr iwalk
#' @importFrom purrr keep
#' @importFrom purrr list_merge
#' @importFrom purrr map
#' @importFrom purrr set_names
#' @importFrom purrr walk
#' @importFrom readr read_csv
#' @importFrom readr read_csv2
#' @importFrom readr write_csv
#' @importFrom readr write_csv2
#' @importFrom rlang is_formula
#' @importFrom rlang sym
#' @importFrom stats as.formula
#' @importFrom stats coef
#' @importFrom stats ecdf
#' @importFrom stats effects
#' @importFrom stats na.omit
#' @importFrom stats pnorm
#' @importFrom stats sd
#' @importFrom stats setNames
#' @importFrom stats terms
#' @importFrom stringr str_remove_all
#' @importFrom tibble as_tibble
#' @importFrom tibble tibble
#' @importFrom tidyr pivot_longer
#' @importFrom utils tail
## usethis namespace: end
NULL

==> adas.utils_1.1.1.tar.gz: adas.utils/R/adas.utils-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr across
#' @importFrom dplyr add_row
#' @importFrom dplyr arrange
#' @importFrom dplyr bind_rows
#' @importFrom dplyr c_across
#' @importFrom dplyr desc
#' @importFrom dplyr filter
#' @importFrom dplyr if_else
#' @importFrom dplyr mutate
#' @importFrom dplyr n
#' @importFrom dplyr pull
#' @importFrom dplyr relocate
#' @importFrom dplyr rename
#' @importFrom dplyr rename_with
#' @importFrom dplyr rowwise
#' @importFrom dplyr select
#' @importFrom dplyr slice_tail
#' @importFrom dplyr summarize_all
#' @importFrom dplyr ungroup
#' @importFrom gghalfnorm gghalfnorm
#' @importFrom ggplot2 aes
#' @importFrom ggplot2 coord_cartesian
#' @importFrom ggplot2 coord_flip
#' @importFrom ggplot2 element_text
#' @importFrom ggplot2 fortify
#' @importFrom ggplot2 geom_col
#' @importFrom ggplot2 geom_errorbar
#' @importFrom ggplot2 geom_function
#' @importFrom ggplot2 geom_hline
#' @importFrom ggplot2 geom_label
#' @importFrom ggplot2 geom_line
#' @importFrom ggplot2 geom_point
#' @importFrom ggplot2 geom_qq
#' @importFrom ggplot2 geom_qq_line
#' @importFrom ggplot2 geom_tile
#' @importFrom ggplot2 ggplot
#' @importFrom ggplot2 labs
#' @importFrom ggplot2 position_dodge
#' @importFrom ggplot2 scale_fill_viridis_d
#' @importFrom ggplot2 scale_y_continuous
#' @importFrom ggplot2 sec_axis
#' @importFrom ggplot2 stat_qq
#' @importFrom ggplot2 theme
#' @importFrom glue glue
#' @importFrom grDevices grey
#' @importFrom lubridate stamp
#' @importFrom purrr accumulate
#' @importFrom purrr discard
#' @importFrom purrr iwalk
#' @importFrom purrr keep
#' @importFrom purrr list_merge
#' @importFrom purrr map
#' @importFrom purrr set_names
#' @importFrom purrr walk
#' @importFrom readr read_csv
#' @importFrom readr read_csv2
#' @importFrom readr write_csv
#' @importFrom readr write_csv2
#' @importFrom rlang :=
#' @importFrom rlang is_formula
#' @importFrom rlang sym
#' @importFrom stats aov
#' @importFrom stats as.formula
#' @importFrom stats coef
#' @importFrom stats ecdf
#' @importFrom stats effects
#' @importFrom stats na.omit
#' @importFrom stats pnorm
#' @importFrom stats sd
#' @importFrom stats setNames
#' @importFrom stats terms
#' @importFrom stats TukeyHSD
#' @importFrom stringr str_remove_all
#' @importFrom tibble as_tibble
#' @importFrom tibble rownames_to_column
#' @importFrom tibble tibble
#' @importFrom tidyr pivot_longer
#' @importFrom utils tail
## usethis namespace: end
NULL
